SizeRange

Struct SizeRange 

pub struct SizeRange(Range<usize>);
The minimum and maximum range/bounds on the size of a collection. The interval must form a subset of [0, std::usize::MAX).

A value like 0..=std::usize::MAX will still be accepted but will silently truncate the maximum to std::usize::MAX - 1.

The Default is 0..PROPTEST_MAX_DEFAULT_SIZE_RANGE. The max can be set with the PROPTEST_MAX_DEFAULT_SIZE_RANGE env var, which defaults to 100.

Tuple Fields

0: Range<usize>

Implementations



impl SizeRange

pub fn new(range: RangeInclusive<usize>) -> SizeRange

Creates a SizeBounds from a RangeInclusive<usize>.

pub fn with<X>(self, and: X) -> (SizeRange, X)

Merges self together with some other argument producing a product type expected by some implementations of A: Arbitrary in A::Parameters. This can be more ergonomic to work with and may help type inference.

pub fn lift<X>(self) -> (SizeRange, X)
where X: Default,

Merges self together with some other argument generated with a default value producing a product type expected by some implementations of A: Arbitrary in A::Parameters. This can be more ergonomic to work with and may help type inference.

pub fn start(&self) -> usize

The lower bound of the range (inclusive).

pub fn start_end_incl(&self) -> (usize, usize)

Extract the ends [low, high] of a SizeRange.

pub fn end_incl(&self) -> usize

The upper bound of the range (inclusive).

pub fn end_excl(&self) -> usize

The upper bound of the range (exclusive).